# eric7.WebBrowser.ZoomManager.ZoomValuesDialog

Module implementing a dialog to show all saved zoom values.

### Global Attributes

None

### Classes

ZoomValuesDialog | Class implementing a dialog to show all saved zoom values.

### Functions

None

## ZoomValuesDialog

Class implementing a dialog to show all saved zoom values.

### Derived from

QDialog, Ui_ZoomValuesDialog

### Class Attributes

None

### Class Methods

None

### Methods

ZoomValuesDialog | Constructor
__calculateHeaderSizes | Private method to calculate the section sizes of the horizontal header.

### Static Methods

None

#### ZoomValuesDialog (Constructor)

ZoomValuesDialog(parent=None)

Constructor

parent
  reference to the parent widget (QWidget)

#### ZoomValuesDialog.__calculateHeaderSizes

__calculateHeaderSizes()

Private method to calculate the section sizes of the horizontal header.

Up